@@ -1,5 +1,4 @@
 from zephyrus_sc2_parser.events.base_event import BaseEvent
-from zephyrus_sc2_parser.gamedata.upgrade_data import upgrades
 
 
 class UpgradeEvent(BaseEvent):
@@ -9,6 +8,7 @@ class UpgradeEvent(BaseEvent):
     def parse_event(self):
         player = self.player
         event = self.event
+        upgrades = self.game.gamedata['upgrades']
 
         if event['m_upgradeTypeName'].decode('utf-8') in upgrades[player.race]:
             player.upgrades.append(event['m_upgradeTypeName'].decode('utf-8'))
