@@ -278,7 +278,8 @@ def parse_replay(filename, *, local=False):
         opp_id = 1 if p_id == 2 else 2
 
         if player.race == 'Zerg':
-            summary_stats['race'][player.player_id]['inject_efficiency'] = current_game.timeline[-1][player.player_id]['race']['inject_efficiency']
+            if 'inject_efficiency' in current_game.timeline[-1][player.player_id]['race']:
+                summary_stats['race'][player.player_id]['inject_efficiency'] = current_game.timeline[-1][player.player_id]['race']['inject_efficiency']
             summary_stats['race'][player.player_id]['avg_idle_larva'] = round(sum(player.idle_larva) / len(player.idle_larva), 1)
             summary_stats['race'][player.player_id]['creep'] = current_game.timeline[-1][player.player_id]['race']['creep']
 
@@ -294,18 +295,18 @@ def parse_replay(filename, *, local=False):
             units = current_game.gamedata['units']
 
             for obj in opp_player.objects.values():
-                if obj.killed_by and obj.killed_by.name in protoss_splash:
-                    protoss_splash[obj.killed_by] = (
-                        protoss_splash[obj.killed_by][0] + units[obj.name]['mineral_cost'],
-                        protoss_splash[obj.killed_by][1] + units[obj.name]['gas_cost'],
+                if 'unit' in obj.type and obj.killed_by and obj.killed_by.name in protoss_splash:
+                    protoss_splash[obj.killed_by.name] = (
+                        protoss_splash[obj.killed_by.name][0] + units[opp_player.race][obj.name]['mineral_cost'],
+                        protoss_splash[obj.killed_by.name][1] + units[opp_player.race][obj.name]['gas_cost'],
                     )
 
             splash_efficiency = {}
             for splash_unit, resources_killed in protoss_splash.items():
                 # if not default
                 if resources_killed != (0, 0):
-                    unit_mineral_cost = units[splash_unit]['mineral_cost']
-                    unit_gas_cost = units[splash_unit]['gas_cost']
+                    unit_mineral_cost = units[player.race][splash_unit]['mineral_cost']
+                    unit_gas_cost = units[player.race][splash_unit]['gas_cost']
 
                     splash_efficiency[splash_unit] = (
                         round(resources_killed[0] / unit_mineral_cost, 2),
